==> ctrlb-prod-fw-1.0.20.tgz: package/index.js <==
var express = require('express'),
    expressSession = require('express-session'),
//    dotenv = require('dotenv').config(),
    mongoose = require('mongoose'),
    bodyParser = require('body-parser'),
    path = require('path'),
    passport = require('passport')

//var app = express()
//const port = process.env.PORT || 3000

require('./models/user') //load the User model
//Bring in the Passport config after model is defined
require('./config/passport')

exports.launch = function(app) {
  //Passport configuration/initialization
  app.use(expressSession({
    secret: process.env.SESSION_SECRET,
    saveUninitialized: true,
    resave: true
  }))
  app.use(passport.initialize())
  app.use(passport.session())

  //Connect to mongodb using mongoose
  var db = mongoose.connect(process.env.DB, {useMongoClient: true})
  db.on('error', console.error.bind(console, 'connection error:'))
  db.once('open', function () {
    console.log('Connection to the db is opened')
  })

  //Call routes
  var routes = require('./routes/router')
  app.use('/api', routes)

  // Create link to Angular build directory
  // var distDir = __dirname + "/../../dist/" //IMPORTANT: __dirname will be node_modules/ctrlb-prod-fw. So need to go back 2 folders to locate dist directory where client angular application will exist
  // app.use(express.static(distDir))
  // app.use(express.static(path.join(__dirname, 'public')))

  app.use(bodyParser.urlencoded({
    extended: true
  }))
  app.use(bodyParser.json())
  //app.use(cors())   //check without this

  //No need of this get route as product framework will be used for api calls only
  // app.get("/", function(req, res) {
  //     res.status(200).sendFile(distDir + 'index.html')
  // })
}

//Not required, coded just for test. This project is for providing api library for most common application functions
// exports.launch = function() {
//     app.listen(port, function(req, res) {
//         console.log('Listening on port ' + port)
//     })
// }

// app.listen(port, function(req, res) {
//   console.log('Listening on port ' + port)
// })

==> ctrlb-prod-fw-1.0.40.tgz: package/index.js <==
var express = require('express'),
    expressSession = require('express-session'),
//    dotenv = require('dotenv').config(),
    mongoose = require('mongoose'),
    bodyParser = require('body-parser'),
    path = require('path'),
    passport = require('passport')

//var app = express()
//const port = process.env.PORT || 3000

require('./models/user') //load the User model
//Bring in the Passport config after model is defined
require('./config/passport')

//Call routes
var routes = require('./routes/router')
module.exports = routes

// exports.signup = function(u) {
//   return routes.signup(u)
// }

exports.launch = function(app) {
  //Passport configuration/initialization
  app.use(expressSession({
    secret: process.env.SESSION_SECRET,
    saveUninitialized: true,
    resave: true
  }))
  app.use(passport.initialize())
  app.use(passport.session())

  //Connect to mongodb using mongoose
  var db = mongoose.connect(process.env.DB, {useMongoClient: true})
  db.on('error', console.error.bind(console, 'connection error:'))
  db.once('open', function () {
    console.log('Connection to the db is opened')
  })

//  app.use('/api', routes)

  // Create link to Angular build directory
  // var distDir = __dirname + "/../../dist/" //IMPORTANT: __dirname will be node_modules/ctrlb-prod-fw. So need to go back 2 folders to locate dist directory where client angular application will exist
  // app.use(express.static(distDir))
  // app.use(express.static(path.join(__dirname, 'public')))

  app.use(bodyParser.urlencoded({
    extended: true
  }))
  app.use(bodyParser.json())
  //app.use(cors())   //check without this

  //No need of this get route as product framework will be used for api calls only
  // app.get("/", function(req, res) {
  //     res.status(200).sendFile(distDir + 'index.html')
  // })
}

//Not required, coded just for test. This project is for providing api library for most common application functions
// exports.launch = function() {
//     app.listen(port, function(req, res) {
//         console.log('Listening on port ' + port)
//     })
// }

// app.listen(port, function(req, res) {
//   console.log('Listening on port ' + port)
// })
